Gitweb:     
http://git.kernel.org/git/?p=linux/kernel/git/torvalds/linux-2.6.git;a=commit;h=ae770152c801f10a91e5e86597a39b5f9ccf2d0d
Commit:     ae770152c801f10a91e5e86597a39b5f9ccf2d0d
Parent:     118a88718886a6cb7fb2cf7fb77ef2eea30c73a1
Author:     Rudolf Marek <[EMAIL PROTECTED]>
AuthorDate: Fri Jan 18 00:50:04 2008 +0100
Committer:  Mark M. Hoffman <[EMAIL PROTECTED]>
CommitDate: Sun Feb 17 22:08:37 2008 -0500

    hwmon: (coretemp) Add Penryn CPU to coretemp
    
    This patch adds support for family 0x17, which has Penryn Core. It should 
also
    cover the 8 cores Xeons.
    
    Can someone test please? I think it should work.
    
    Signed-off-by: Rudolf Marek <[EMAIL PROTECTED]>
    Acked-by: Jean Delvare <[EMAIL PROTECTED]>
    Signed-off-by: Mark M. Hoffman <[EMAIL PROTECTED]>
---
 Documentation/hwmon/coretemp |    3 ++-
 drivers/hwmon/coretemp.c     |    4 ++--
 2 files changed, 4 insertions(+), 3 deletions(-)

diff --git a/Documentation/hwmon/coretemp b/Documentation/hwmon/coretemp
index 7fb7441..dbbe6c7 100644
--- a/Documentation/hwmon/coretemp
+++ b/Documentation/hwmon/coretemp
@@ -4,9 +4,10 @@ Kernel driver coretemp
 Supported chips:
   * All Intel Core family
     Prefix: 'coretemp'
-    CPUID: family 0x6, models 0xe, 0xf, 0x16
+    CPUID: family 0x6, models 0xe, 0xf, 0x16, 0x17
     Datasheet: Intel 64 and IA-32 Architectures Software Developer's Manual
                Volume 3A: System Programming Guide
+               http://softwarecommunity.intel.com/Wiki/Mobility/720.htm
 
 Author: Rudolf Marek
 
diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
index 1f34ad8..70239ac 100644
--- a/drivers/hwmon/coretemp.c
+++ b/drivers/hwmon/coretemp.c
@@ -413,10 +413,10 @@ static int __init coretemp_init(void)
        for_each_online_cpu(i) {
                struct cpuinfo_x86 *c = &cpu_data(i);
 
                /* check if family 6, models e, f, 16 */
                if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
                    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
-                       (c->x86_model == 0x16))) {
+                       (c->x86_model == 0x16) || (c->x86_model == 0x17))) {
 
                        /* supported CPU not found, but report the unknown
                           family 6 CPU */
-
@@ -413,10 +413,10 @@ static int __init coretemp_init(void)
                struct cpuinfo_x86 *c = &cpu_data(i);
 
-               /* check if family 6, models e, f, 16 */
+               /* check if family 6, models 0xe, 0xf, 0x16, 0x17 */
                if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
                    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
To unsubscribe from this list: send the line "unsubscribe git-commits-head" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to